@@ -20,10 +20,11 @@ from .generator.file import get_path_from_root
 from distutils.dir_util import copy_tree
 
 DOCKER_NETWORK = 'deadlock-challenge'
-PREFIX_SERVICE_NAME='deadlock-service'
-PERSIST_DOCKER_NAME="deadlock-persist-mission"
+PREFIX_SERVICE_NAME = 'deadlock-service'
+PERSIST_DOCKER_NAME = "deadlock-persist-mission"
 
-def build(tag, path):
+
+def build(tag, path, verbose=False):
     spin = SpinCursor('', speed=5, maxspin=100000)
     if (os.path.exists(path) == False):
         error('Directory does not exist ' + path)
@@ -38,39 +39,45 @@ def build(tag, path):
             'spin': spin})
     info('🐳 Building Docker image')
     execute(f'docker build {path} -q -t {tag}', {
-            'quiet': True,
-            'exitOnError': True,
-            'spin': spin})
+        'quiet': not verbose,
+        'exitOnError': True,
+        'spin': spin})
 
-    execute(f'docker network create {DOCKER_NETWORK}', {'quiet': True})
+    execute(f'docker network create {DOCKER_NETWORK}', {'quiet': not verbose})
 
     # also build services if exist
     if os.path.exists(f'{path}/services') == True:
         dirs = os.listdir(f'{path}/services')
         for service in dirs:
             build_and_run_service(f'{path}/services', service)
-            
+
     spin.stop()
 
+
 def build_and_run_service(path, service):
     info(f'📂 {service} service found')
     info(f'>  🐳 Building {service}')
-    execute(f'docker build -q -f {path}/{service}/Dockerfile -t {get_docker_service_name(service)} {path}/{service}', {"quiet": False})
+    execute(f'docker build -q -f {path}/{service}/Dockerfile -t {get_docker_service_name(service)} {path}/{service}',
+            {"quiet": False, "exitOnError": True, "messageOnError": f'Building {service} failed'})
     info(f'>  🚀 Running {service}')
-    execute(f'docker run -d --rm --net={DOCKER_NETWORK} --name {service} {get_docker_service_name(service)}', {"quiet": False})
+    execute(f'docker run -d --rm --net={DOCKER_NETWORK} --name {service} {get_docker_service_name(service)}',
+            {"quiet": False, "exitOnError": True, "messageOnError": f'Running {service} failed'})
 
 
 def get_docker_service_name(serviceName):
     return f'{PREFIX_SERVICE_NAME}-{serviceName}'
 
-def clean():
+
+def clean(verbose=False):
     print('')
     time.sleep(1)
     info('Cleaning resources')
-    execute(f'docker ps --filter network={DOCKER_NETWORK} -aq | xargs -r docker stop >/dev/null | xargs -r docker rm', {"quiet": True})
-    execute(f'docker network rm {DOCKER_NETWORK}', {"quiet": True})
+    execute(f'docker ps --filter network={DOCKER_NETWORK} -aq | xargs -r docker stop >/dev/null | xargs -r docker rm',
+            {"quiet": not verbose})
+    execute(f'docker network rm {DOCKER_NETWORK}', {"quiet": not verbose})
     info('Done')
 
+
 def prepare_metamorph_code(path, tmpDir):
     info('🔨 Building mission..')
     spin = SpinCursor('', speed=5, maxspin=100000)
@@ -86,17 +93,18 @@ def prepare_metamorph_code(path, tmpDir):
             for file in files:
                 shutil.copy(os.path.join(subdir, file), tmpDir)
 
-
         os.system('docker build ' + tmpDir + ' -q -t meta')
     finally:
         spin.stop()
 
+
 def run_metamorph_code(path, language):
-   exec_metamorph_code(path, language, 'run') 
+    exec_metamorph_code(path, language, 'run')
+
 
 def solve_metamorph_code(path, language):
-   exec_metamorph_code(path, language, 'solve') 
-    
+    exec_metamorph_code(path, language, 'solve')
+
 
 def exec_metamorph_code(path, language, way):
     if path == '.':
@@ -104,7 +112,7 @@ def exec_metamorph_code(path, language, way):
     elif path[0] != '/':
         error('Path given must be absolute')
         exit(1)
-        
+
     download_if_necessary(path)
 
     # copy everything to tmp to avoid any conflict with user directory files
@@ -127,10 +135,11 @@ def download_if_necessary(path):
 
     if should_download == True:
         download_runner(path)
-    
+
+
 def download_runner(path):
     url = "https://builder.staging.deadlock.io/build"
-    
+
     info('🛰️  Download runner based on your entry.rs file.')
     info('Operation will be long the first time, no worries.')
 
@@ -161,19 +170,21 @@ def download_runner(path):
     info('🛰️  Download completed')
 
 
-def run_code(path=os.getcwd()):
+def run_code(path=os.getcwd(), verbose=False):
     tag = uuid.uuid4()
-    build(tag, path) 
+    build(tag, path, verbose)
     info('🚀 Running mission..')
     execute(f'docker run --net={DOCKER_NETWORK} {tag} Run')
     pass
 
+
 def run_hack(path=os.getcwd()):
     os.system(get_path_from_root('utils/run-hack.sh'))
 
-def run_persist(path=os.getcwd()):
+
+def run_persist(path=os.getcwd(), verbose=False):
     info('Remove previous mission..')
-    execute(f'docker rm {PERSIST_DOCKER_NAME} -f', {'quiet': True})
+    execute(f'docker rm {PERSIST_DOCKER_NAME} -f', {'quiet': not verbose})
 
     yaml = load_yaml(path + '/' + CHALLENGE_YAML)
 
@@ -201,20 +212,22 @@ def run_persist(path=os.getcwd()):
 
     # start docker container
     tag = uuid.uuid4()
-    build(tag, path) 
+    build(tag, path, verbose)
     info('🚀 Running mission..')
-    
-    execute(f'docker run --net={DOCKER_NETWORK} -v {userConfigPath}:/home/config/user-challenge.json -d {portsCmd} --name {PERSIST_DOCKER_NAME} {tag}', {'quiet': True, 'exitOnError': True})
+
+    execute(
+        f'docker run --net={DOCKER_NETWORK} -v {userConfigPath}:/home/config/user-challenge.json -d {portsCmd} --name {PERSIST_DOCKER_NAME} {tag}',
+        {'quiet': not verbose, 'exitOnError': True})
     info('🌐 You can view the mission in the browser:')
     info('🌐 http://localhost:3000')
 
     while True:
         try:
-           sys.stdin.readline()
+            sys.stdin.readline()
         except KeyboardInterrupt:
             info('Cleaning mission..')
-            execute(f'docker rm {PERSIST_DOCKER_NAME} -f', {'quiet': True})
-            clean()
+            execute(f'docker rm {PERSIST_DOCKER_NAME} -f', {'quiet': not verbose})
+            clean(verbose)
             sys.exit()
 
 
@@ -234,7 +247,8 @@ def solve_score(tag, path=os.getcwd()):
 
     info('Writing file..')
     tmpPathFile = create_tmp_folder() + '/' + MISSION_USER_SCORE_FILENAME
-    missionUserScore = MissionUserScore(str(uuid.uuid4()), f'http://{API_ADRESS}:{str(API_PORT)}{MISSION_USER_SCORE_ENDPOINT}').__dict__
+    missionUserScore = MissionUserScore(str(uuid.uuid4()),
+                                        f'http://{API_ADRESS}:{str(API_PORT)}{MISSION_USER_SCORE_ENDPOINT}').__dict__
     missionUserScoreJson = json.dumps(missionUserScore)
     write_file(tmpPathFile, missionUserScoreJson)
 
@@ -248,7 +262,8 @@ def solve_code(tag, path=os.getcwd()):
     os.system(f'docker run --net={DOCKER_NETWORK} {tag} Solve')
     pass
 
-def solve(path=os.getcwd(), language='empty'):
+
+def solve(path=os.getcwd(), language='empty', verbose=False):
     '''
     Run Solve step for the mission under given path.
     As if user clicked on Submit button.
@@ -265,18 +280,18 @@ def solve(path=os.getcwd(), language='empty'):
             solve_metamorph_code(path, language)
         elif 'score' in yaml['coding']:
             tag = uuid.uuid4()
-            build(tag, path)
+            build(tag, path, verbose)
             solve_score(tag, path)
         else:
             tag = uuid.uuid4()
-            build(tag, path)
+            build(tag, path, verbose)
             solve_code(tag, path)
     else:
         error('Challenge type not supported for solve method.')
-    clean()
+    clean(verbose)
 
 
-def run(path=os.getcwd(), language='empty'):
+def run(path=os.getcwd(), language='empty', verbose=False):
     '''
     Run the mission under given path.
     As if user clicked on Run button.
@@ -286,19 +301,20 @@ def run(path=os.getcwd(), language='empty'):
     exit_if_no_challenge_file(path)
     yaml = load_yaml(path + '/' + CHALLENGE_YAML)
     if yaml['type'] == 'PERSISTENT':
-        run_persist(path)
+        run_persist(path, verbose)
     elif 'coding' in yaml:
         if os.path.exists(f'{path}/entry.rs') == True:
             run_metamorph_code(path, language)
         else:
-            run_code(path)
+            run_code(path, verbose)
     elif 'hacking' in yaml:
         run_hack(path)
     else:
         error('Challenge type not supported, verify your challenge.yaml')
-    clean()
+    clean(verbose)
+
 
 def exit_if_no_challenge_file(path):
     if os.path.exists(path + '/' + CHALLENGE_YAML) == False:
         error('You have to be within a challenge folder to execute your command.')
-        sys.exit(1)
\ No newline at end of file
+        sys.exit(1)
